"""
    Some functions for pdf handlings__

"""

def pages_pdf(inputfile):

    from PyPDF2 import PdfReader

    file = open(inputfile, 'rb')
    pdfReader = PdfReader(file)
    return len(pdfReader.pages)


def create_files(filepath, n, nf, extension):
	"""
	This function takes four inputs and returns tex filenames with proper path 
	
	    filepath -> path to be modified with filename
	    n -> nth of files to be produced
	    nf -> number of files to be produced
        extension -> file extension
	
	    Eg: filepath = "./test/main.tex" -> "./test/main-0.tex, main-1.tex" like that
	"""
	path = filepath.split('.')
	pathinit = filepath.split('/')
	if nf == 1:
	    if pathinit[0] == '.':
	        return '.' + path[len(path)-2] + '.' + extension
	    else:
	        return path[len(path)-2] + '.' + extension
	else:
	    if pathinit[0] == '.':
	        return '.' + path[len(path)-2] + '-' + str(n + 1) +  '.' + extension
	    else:
	        return path[len(path)-2] + '-' + str(n + 1) + '.' + extension
	

def extract_png_pdf(inputfile, first_page, last_page, outputfile, dpi, transparent):
    """
    keyword args:
        inputfile <- Path
        first_page <- Int
        last_page <- Int
        outputfile <- Path
        dpi <- Int
        transparent <- Bool
    """

    from PyPDF2 import PdfReader
    from pdf2image import convert_from_path

    pages = convert_from_path(
            "./{}".format(inputfile), 
            first_page=first_page,
            last_page=last_page,
            dpi=dpi,
            transparent = transparent,
            use_pdftocairo = True,
            thread_count=8
            )
    file = open(inputfile, 'rb')
    pdfReader = PdfReader(file)
    n_pages = len(pdfReader.pages)

    for i in range(first_page, last_page+1):
        file_name = create_files(
                outputfile,
                i-1,
                n_pages,
                'png'
                )
        pages[i-first_page].save(f'{file_name}', 'PNG')
        print(f'{inputfile} page {i} -> {file_name}')




import click

from .split import split
from .overlay import overlay
#from .compress import compress
from .topng import topng
from .addbg import addbg

CONTEXT_SETTINGS = dict(
        help_option_names = [
            '-h',
            '--help'
        ]
)

@click.group(context_settings=CONTEXT_SETTINGS)
def main():
    pass




main.add_command(split)
main.add_command(overlay)
main.add_command(topng)
main.add_command(addbg)
#main.add_command(compress)



import click
import os
import time

from PyPDF2 import PdfReader, PdfWriter


@click.command(
        help="Splits any pdf file."
        )
@click.option(
        '-i',
        '--inputfile',
        type=click.Path(),
        default='./main.pdf',
        show_default=True,
        help="Input file",
        )
@click.option(
        '-o',
        '--outputfile',
        type=click.Path(),
        default='./main_splited.pdf',
        show_default=True,
        help="Output file"
        )
@click.option(
        '-p',
        '--pages',
        type=click.Tuple([int, int]),
        default=(0, 0),
        show_default=True,
        help="Pages range"
        )
def split(inputfile, outputfile, pages):

    inputpdf = open(inputfile, 'rb')
    reader = PdfReader(inputpdf)

    writer = PdfWriter()
    for i in range(pages[0], pages[1]+1):
        writer.add_page(reader.pages[i-1])
    with open(outputfile, 'wb') as outputpdf:
        writer.write(outputpdf)





import click
import os
from PIL import Image

bg_path = "/Users/vaibhavblayer/10xphysics/backgrounds/bg_instagram.jpg"


@click.command(
        help="Adds background to any transparent image"
        )
@click.option(
        '-i', 
        '--image', 
        type=click.Path(),
        default="./main.png",
        help="Front Image"
        )
@click.option(
        '-b', 
        '--background', 
        type=click.Path(),
        default=bg_path,
        help="Background Image"
        )
def addbg(image, background):
    background = Image.open(background)
    frontImage = Image.open(image)
    frontImage = frontImage.convert("RGBA")
    background = background.convert("RGBA")
    background = background.resize((frontImage.width, frontImage.height))
    width = (background.width - frontImage.width) // 2
    height = (background.height - frontImage.height) // 2
    background.paste(frontImage, (width, height), frontImage)
    background.save("new.png", format="png")

    click.echo(f'{image} is overlayed on top of the background.')

#    with click.progressbar([1, 2, 3]) as bar:
#        for x in bar:
#            print(f"sleep({x})...")
#            time.sleep(x)











import click
import os
import sys
import PyPDF2
import time
from rich.console import Console
from .functions_pdf import pages_pdf
from .functions_pdf import extract_png_pdf



@click.command(
        help="Converts pdf pages into pngs"
        )
@click.option(
        '-i',
        '--inputfile',
        type=click.Path(),
        default="./main.pdf",
        show_default=True,
        help="Input file name"
        )
@click.option(
        '-o',
        '--outputfile',
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Output file name"
        )
@click.option(
        '-d',
        '--dpi',
        default=320,
        type=click.INT,
        show_default=True,
        help="DPI -> density per inch for png"
        )
@click.option(
        '-t',
        '--transparent',
        is_flag=True,
        default=False,
        show_default=True,
        help="Use this flag for transparent png"
        )
@click.option(
        '-r',
        '--ranges',
        nargs=2,
        default=([1, 1]),
        type=click.Tuple([int, int]),
        show_default=True,
        help="Page range to be converted into png"
        )
@click.option(
        '-p',
        '--pages',
        default=False,
        is_flag = True,
        show_default=True,
        help="Shows no of pages in a pdf file"
        )
def topng(inputfile, outputfile, dpi, transparent, ranges, pages):
    mydict = {
            'inputfile': inputfile,
            'first_page': ranges[0],
            'last_page': ranges[1],
            'outputfile': outputfile,
            'dpi': dpi,
            'transparent': transparent
            }

    time_init = int(time.strftime('%s'))
    if pages == True:
        n_pages = pages_pdf(inputfile)
        print(f'Total number of pages is {n_pages}')
    else:
        console = Console(width=50)
        with console.status("Processing ...", spinner="pong"):
            extract_png_pdf(**mydict)
        time_finish = int(time.strftime('%s'))
        print(f'Took {time_finish - time_init} seconds to do it')






import click

from PyPDF2 import PdfReader, PdfWriter
from PyPDF2.generic import AnnotationBuilder



@click.command(
        help="Annotates any pdf file."
        )
@click.option(
        '-i',
        '--inputfile',
        type=click.Path(),
        default='./main.pdf',
        show_default=True,
        help="Input file",
        )
@click.option(
        '-o',
        '--outputfile',
        type=click.Path(),
        default='./main_annotated.pdf',
        show_default=True,
        help="Output file"
        )
@click.option(
        '-s',
        '--size',
        is_flag=True,
        default=False,
        show_default=True,
        help="For checking size of the pdf"
        )
@click.option(
        '-t',
        '--text',
        type=click.STRING,
        default="Hello Sir!",
        show_default=True,
        help="Text to be placed"
        )
@click.option(
        '-p',
        '--position',
        type=click.Tuple([int, int, int, int]),
        default=(0, 0, 100, 100),
        show_default=True,
        help="Coordintes of the tex box"
        )
@click.option(
        '-f',
        '--foreground_color',
        default='000000',
        show_default=True,
        help='Foreground Color'
        )
@click.option(
        '-b',
        '--background_color',
        default='ffffff',
        show_default=True,
        help='Background Color'
        )
@click.option(
        '-F',
        '--font',
        default="Courier",
        type=click.STRING,
        show_default=True,
        help="Font type"
        )
@click.option(
        '--font_size',
        default=24,
        show_default=True,
        help='Font size'
        )
def overlay(inputfile, outputfile, size, text, font, position, foreground_color, background_color, font_size):

    inputpdf = open(inputfile, 'rb')
    reader = PdfReader(inputpdf)
    if size:
        for i in enumerate(reader.pages):
            w = i[1].artbox.width
            h = i[1].artbox.height
            print(f'Page: {i[0]+1} \t Height: {h} \t Width: {w}')

    else:
        writer = PdfWriter()
        text_box = AnnotationBuilder.free_text(
                text,
                rect=position,
                font="Courier",
                font_size=str(font_size)+'pt',
                font_color=foreground_color,
                border_color=foreground_color,
                background_color=background_color
                )

        rectangle_box = AnnotationBuilder.rectangle(
                rect=position,
                interiour_color=background_color,
                )
    
        for page in enumerate(reader.pages):
            writer.add_page(page[1])
            writer.add_annotation(page_number=page[0], annotation=text_box)
        with open(outputfile, 'wb') as outputpdf:
            writer.write(outputpdf)
